# 北京盒子hub部署

> ### Nginx

```shel
docker pull harbor-albj.baijiayun.com/ai_architecture/nginx:v1
docker run -m 200M  --restart=always --name=nginx --net=host -d -v /home/nginx/content:/usr/share/nginx/html:ro -v /home/nginx/conf.d:/etc/nginx/conf.d:ro -v /home/nginx/conf.d:/var/log/nginx/:rw -v /data2/ai-algo-aat:/data2/ai-algo-aat:rw harbor-albj.baijiayun.com/ai_architecture/nginx:v1
```

> ### Mysql	

```shel
docker pull harbor-albj.baijiayun.com/ai_architecture/mysql:v1
docker run  -m 200M  --restart=always --name mysql --net=host -e MYSQL_ROOT_PASSWORD=123456 -v /home/nvidia/data/mysql:/var/lib/mysql --privileged=true -d harbor-albj.baijiayun.com/ai_architecture/mysql:v1
```

> ### Redis

```shel
docker pull harbor-albj.baijiayun.com/ai_architecture/redis:v1
docker run --name redis  -m 200M  --restart=always --net=host -d harbor-albj.baijiayun.com/ai_architecture/redis:v1 --requirepass "123456" 
```

> ### Boliving

```shell
docker pull harbor-albj.baijiayun.com/ai_architecture/boliving-arm:v1
docker run -itd --name boliving harbor-albj.baijiayun.com/ai_architecture/boliving-arm:v1 /bin/bash

#copy一份配置文件到本地
mkdir -p /home/nvidia/docker_compose/boliving
docker cp boliving:/boliving/bin/ /home/nvidia/docker_compose/boliving/bin
#停止镜像 
docker stop boliving
docker rm boliving
#修改配置信息
cd  /home/nvidia/docker_compose/boliving/bin
vim config.toml 

#1 [Nacos]
#2 Enable=true
#3 ServerIP="127.0.0.1"
#4 ServerPort=8848
...
#26 [RTMP]
#27 ListenAddr = ":8083"
#28 [GateWay]
#29 ListenAddr = ":8081"
新加
TraceApi = "/api/boom/getBySerial"
RTCSAddr = "http://127.0.0.1:6060"
...
#46 RTSP]
#47 Timeout = 20
#48 AutoPull = false
#49 RemoteAddr = "rtsp://localhost/test"
#50 ListenAddr = ":8085"

#启动镜像，进行目录挂在
docker run -itd --net=host --name boliving  -v /home/nvidia/docker_compose/boliving/bin:/boliving/bin harbor-albj.baijiayun.com/ai_architecture/boliving-arm:v1 /bin/bash
#进入映射目录，修改配置文件.
docker exec -it boliving /bin/bash
cd /boliving/bin
./boliving -c ./config.toml&
```

> ### JDK

```shell
sudo apt-get install openjdk-8-jdk
java -version
#上传平台的jar包
nohup java -jar start.jar  &
#便可登录平台
```

> ### 自动启动脚本 step.sh

```she
#!/bin/bash
# 启动 算法 服务
docker restart ai_platform_test
# 启动 redis 服务
docker restart redis
# 启动 nginx 服务
docker restart nginx
# 启动 mysql 服务
docker restart mysql
# 启动 java 服务
ps -ef | grep "java"| grep -v grep | awk '{print $2}'| xargs kill -9
 
cd /home/nvidia/docker_compose

nohup java -jar start.jar &
# 启动 boliving 服务
docker restart boliving
docker exec -d boliving bash -c 'cd /boliving/bin/ && ./boliving -c ./config.toml'
```

> ### 静态资源迁移

```shell
mkdir -p /data2/ai-algo-aat/upload/comm
chown nvidia /data2/ai-algo-aat/upload -R
#迁移文件 1647496478066_Baidu_217__2022-03-04_0001.jpeg
mkdir -p /home/nvidia/docker_compose/license/
chown nvidia /home/nvidia/ -R
#迁移license文件
```







 docker-compose down
docker-compose up --build -d















































# 盒子部署算法

> Mysql

```shell
docker pull mysql:8.0-oracle
docker run -d --name -m 200M mysql -e MYSQL_ROOT_PASSWORD=123456 -p 3306:3306 -v /home/nvidia/data/mysql:/var/lib/mysql  mysql:8.0-oracle
#然后链接mysql数据库进行数据导入
```

> Redis

```shell
docker run --name redis -m 200M -v /home/nvidia/data/redis/:/etc -p 6379:6379 -d redis:6.0.16

docker run --name redis -p 6379:6379 -d redis:6.0.16
```

> Nginx

```shell
docker run --name nginx -m 200M -d -p 80:80 -v /home/nginx/content:/usr/share/nginx/html:ro -v /home/nginx/conf.d:/etc/nginx/conf.d:ro -v /home/nginx/conf.d:/var/log/nginx/:rw -v /nas/ai-algo-aat:/nas/ai-algo-aat:rw nginx:1.18-alpine
```

> Nginx配置信息：
>
> 注意修改： proxy_pass http://宿主机IP:6060;

  ```yaml
cd /home/nginx/conf.d

server {
    listen       80;
    listen  [::]:80;
    server_name  localhost;

    #charset koi8-r;
    access_log  /var/log/nginx/host.access.log  main;

    location / {
        root   /usr/share/nginx/html/dist;
        index  index.html index.htm;
    }
	location /dist/ {
         root /usr/share/nginx/html/;
            index  index.html index.htm;
            proxy_redirect off;
        }

        location /img/ {
            root /data/ai-algo-aat/upload/;
            autoindex on;
        }
        location /upload/ {
            root /nas/ai-algo-aat/;
            autoindex on;
        }
        location /collect/ {
            root /nas/ai-algo-aat/;
            autoindex on;
        }
        

        location /comm/ {
            root /mnt/ip230_data2/ai-algo-aat/upload/;
            autoindex on;
        }

	location /api/ {
            if ($request_method = 'OPTIONS') {
                add_header 'Access-Control-Allow-Origin' '*' always;
                add_header 'Access-Control-Allow-Credentials' 'true';
                add_header 'Access-Control-Allow-Methods' 'GET, POST, PATCH, DELETE, PUT, OPTIONS';
                add_header 'Access-Control-Allow-Headers' 'DNT,X-Mx-ReqToken,Keep-Alive,User-Agent,X-Requested-With,If-Modified-Since,Cache-Control,Content-Type, Access-Control-Expose-Headers,Token,Authorization,X-Auth-Token,x-auth-token';
                add_header 'Access-Control-Max-Age' 1728000;
                #add_header 'Content-Type' 'text/plain charset=UTF-8';
                add_header 'Content-Length' 0;
                return 200;   
            }

            add_header Access-Control-Allow-Headers 'Content-Type,Token,Authorization,X-Auth-Token,x-auth-token';
            add_header Access-Control-Allow-Origin *;
            add_header Access-Control-Allow-Credentials true; 
    
            root   html;
            index  index.html index.htm;
            proxy_set_header X-Real-IP $remote_addr;
            proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
            proxy_set_header Host $host:$server_port;
            proxy_pass http://10.8.26.61:6060;
            proxy_redirect off;
            client_max_body_size 1024M;
        }

    #error_page  404              /404.html;

    # redirect server error pages to the static page /50x.html
    #
    error_page   500 502 503 504  /50x.html;
    location = /50x.html {
        root   /usr/share/nginx/html;
    }

    # proxy the PHP scripts to Apache listening on 127.0.0.1:80
    #
    #location ~ \.php$ {
    #    proxy_pass   http://127.0.0.1;
    #}

    # pass the PHP scripts to FastCGI server listening on 127.0.0.1:9000
    #
    #location ~ \.php$ {
    #    root           html;
    #    fastcgi_pass   127.0.0.1:9000;
    #    fastcgi_index  index.php;
    #    fastcgi_param  SCRIPT_FILENAME  /scripts$fastcgi_script_name;
    #    include        fastcgi_params;
    #}

    # deny access to .htaccess files, if Apache's document root
    # concurs with nginx's one
    #
    #location ~ /\.ht {
    #    deny  all;
    #}
}

  ```

> 前端项目：
>
> 直接dist目录放到挂在目录中：`/home/nginx/content`。访问IP即可访问！

> Boliving

```shell
#先将tar包导入到服务器，并生成镜像
docker load --input boliving-arm:bing.1.0.0.03121.tar

#运行镜像
docker run -itd --name boliving registry.cn-beijing.aliyuncs.com/webrtc-boom/boliving-arm:bing.1.0.0.03121  /bin/bash
#copy一份配置文件到本地
mkdir /home/nvidia/boliving
docker cp boliving:/boliving/bin/ /home/nvidia/boliving/bin

#停止镜像 
docker stop [boliving容器id]
docker rm [boliving容器id]

#启动镜像，进行目录挂在
docker run --net=host -v /home/nvidia/boliving/bin:/boliving/bin registry.cn-beijing.aliyuncs.com/webrtc-boom/boliving-arm:bing.1.0.0.03121 

docker run -itd --net=host -v /home/nvidia/boliving/bin:/boliving/bin registry.cn-beijing.aliyuncs.com/webrtc-boom/boliving-arm:bing.1.0.0.03121 /bin/bash
#进入映射目录，修改配置文件.
cd  /home/nvidia/docker_compose/boliving/bin
vim config.toml 
# ListenAddr 修改为 ":8083"  ListenAddr 修改为 ":8085"  RTCSAddr 修改为 "http://宿主机IP:6060"
#26 [RTMP]
#27 ListenAddr = ":8083"
#28 [GateWay]
#29 ListenAddr = ":8081"
#新加
#30 TraceApi = "/api/boom/getBySerial"
#31 RTCSAddr = "http://127.0.0.1:6060"
...
#46 RTSP]
#47 Timeout = 20
#48 AutoPull = false
#49 RemoteAddr = "rtsp://localhost/test"
#50 ListenAddr = ":8085"

#重启容器
docker restart [boliving容器id]
#进入容器
docker attach [boliving容器id]



cd /boliving/bin
./boliving -c ./config.toml&


#访问ip:8081,能够访问的话，证明安装成功
```

> JDK

```shell
sudo apt-get install openjdk-8-jdk
java -version
#上传平台的jar包
nohup java -jar start.jar > runtimelogs.log 2>&1 &
#便可登录平台
```

> 推流

```shell
ffmpeg -i 'rtsp://admin:admin123@172.31.100.59:554/cam/realmonitor?channel=2&subtype=0' -codec copy -f rtsp rtsp://172.31.2.124:8085/ai/rtsp
```

> ai平台添加`rtsp://172.31.2.124:8085/ai/rtsp`即可在线预览与视频截帧分析

```shell
docker run --name mysql --net=host -e MYSQL_ROOT_PASSWORD=123456 -v /home/nvidia/ai/data/mysql:/var/lib/mysql -d mysql:8.0-oracle

docker run --name redis --net=host -d redis:6.0.16 --requirepass "654321"

docker run --name=nginx --net=host -d -v /home/nginx/content:/usr/share/nginx/html:ro -v /home/nginx/conf.d:/etc/nginx/conf.d:ro -v /home/nginx/conf.d:/var/log/nginx/:rw -v /data2/ai-algo-aat:/data2/ai-algo-aat:rw nginx:1.18-alpine


```



```tex
/pc/algo/version/trainCallback   算法训练的结果回调通知
/pc/algo/version/modelCallback    模型的结果回调通知
/pc/algoApp/algoImgResultCallback   算法应用-图片应用结果回调
/collectionTask/collectionCallback	采集回调通知
/deployAuthorizeUsers/callback 部署包结果回调接口
/onlineVideoStream/onOrOffCallBack		视频流开启成功/失败后的回调
/onlineVideoStream/modelCallback		分析回调
```











通过培训，我们深刻体会到，如果想要成为一个优秀的员工，就要完全的表现出自己的优势，自己的个人价值，包括提升自己的能力、性格、态度、知识面等。

我们员工的知识面以及个人价值，能够体现出我们在用户心目中的定位，整体代表的公司在用户心目中的价值。更好的价值体现能够为公司提供一个良好的信誉与荣耀。

通过了藏药只是体系的讲解与培训，让我们对藏药的起源与发展有了很大的了解，作为即将为产品服务的我们来说，提高对药物信息的掌握，有助于我们更好的去引导用户，更有利的宣传公司产品的价值。也能够通过我们的专业知识，给用户带来更好的信任。
